@@ -23,18 +23,20 @@ along with pyscard; if not, write to the Free Software
 Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 """
 
+# pylint: disable=too-few-public-methods
+
 
 class CardConnectionEvent:
     """Base class for card connection events.
 
     This event is notified by CardConnection objects."""
 
-    def __init__(self, type, args=None):
+    def __init__(self, event_type, args=None):
         """
-        @param type:   'connect', 'reconnect', 'disconnect', 'command', 'response'
+        @param event_type:   'connect', 'reconnect', 'disconnect', 'command', 'response'
         @param args:   None for 'connect', 'reconnect' or 'disconnect'
                 command APDU byte list for 'command'
                 [response data, sw1, sw2] for 'response'
         """
-        self.type = type
+        self.type = event_type
         self.args = args
