@@ -6,7 +6,7 @@ upon smart card insertion/removal.
 CardMonitor is a singleton object notifying registered CardObservers
 upon reader insertion/removal.
 
-__author__ = "http://www.gemalto.com"
+__author__ = "https://www.gemalto.com/"
 
 Copyright 2001-2012 gemalto
 Author: Jean-Daniel Aussel, mailto:jean-daniel.aussel@gemalto.com
@@ -28,19 +28,19 @@ along with pyscard; if not, write to the Free Software
 Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 """
 
-from threading import Thread, Event
-from time import sleep
 import traceback
-
-from smartcard.Observer import Observer
-from smartcard.Observer import Observable
+from threading import Event, Lock, Thread
+from time import sleep
 
 from smartcard.CardRequest import CardRequest
-from smartcard.Exceptions import SmartcardException
+from smartcard.Exceptions import CardRequestTimeoutException, SmartcardException
+from smartcard.Observer import Observable, Observer
 from smartcard.scard import SCARD_E_NO_SERVICE
 
 _START_ON_DEMAND_ = False
 
+# pylint: disable=too-few-public-methods
+
 
 # CardObserver interface
 class CardObserver(Observer):
@@ -60,10 +60,9 @@ class CardObserver(Observer):
           - addedcards: list of inserted smart cards causing notification
           - removedcards: list of removed smart cards causing notification
         """
-        pass
 
 
-class CardMonitor(object):
+class CardMonitor:
     """Class that monitors smart card insertion / removals.
     and notify observers
 
@@ -119,20 +118,22 @@ class CardMonitor(object):
                         self.rmthread = None
 
         def __str__(self):
-            return 'CardMonitor'
+            return "CardMonitor"
 
     # the singleton
     instance = None
+    lock = Lock()
 
     def __init__(self):
-        if not CardMonitor.instance:
-            CardMonitor.instance = CardMonitor.__CardMonitorSingleton()
+        with CardMonitor.lock:
+            if not CardMonitor.instance:
+                CardMonitor.instance = CardMonitor.__CardMonitorSingleton()
 
     def __getattr__(self, name):
         return getattr(self.instance, name)
 
 
-class CardMonitoringThread(object):
+class CardMonitoringThread:
     """Card insertion thread.
     This thread waits for card insertion.
     """
@@ -150,47 +151,38 @@ class CardMonitoringThread(object):
             self.stopEvent = Event()
             self.stopEvent.clear()
             self.cards = []
-            self.setDaemon(True)
+            self.daemon = True
+            self.cardrequest = None
 
         # the actual monitoring thread
         def run(self):
             """Runs until stopEvent is notified, and notify
             observers of all card insertion/removal.
             """
-            self.cardrequest = CardRequest(timeout=0.1)
-            while self.stopEvent.isSet() != 1:
+            self.cardrequest = CardRequest(timeout=60)
+            while not self.stopEvent.is_set():
                 try:
                     currentcards = self.cardrequest.waitforcardevent()
 
                     addedcards = []
                     for card in currentcards:
-                        if not self.cards.__contains__(card):
+                        if card not in self.cards:
                             addedcards.append(card)
 
                     removedcards = []
                     for card in self.cards:
-                        if not currentcards.__contains__(card):
+                        if card not in currentcards:
                             removedcards.append(card)
 
-                    if addedcards != [] or removedcards != []:
+                    if addedcards or removedcards:
                         self.cards = currentcards
                         self.observable.setChanged()
-                        self.observable.notifyObservers(
-                            (addedcards, removedcards))
+                        self.observable.notifyObservers((addedcards, removedcards))
 
-                # when CardMonitoringThread.__del__() is invoked in
-                # response to shutdown, e.g., when execution of the
-                # program is done, other globals referenced by the
-                # __del__() method may already have been deleted.
-                # this causes ReaderMonitoringThread.run() to except
-                # with a TypeError or AttributeError
-                except TypeError:
-                    pass
-                except AttributeError:
+                except CardRequestTimeoutException:
                     pass
 
                 except SmartcardException as exc:
-                    # FIXME Tighten the exceptions caught by this block
                     traceback.print_exc()
                     # Most likely raised during interpreter shutdown due
                     # to unclean exit which failed to remove all observers.
@@ -199,51 +191,52 @@ class CardMonitoringThread(object):
                     if exc.hresult == SCARD_E_NO_SERVICE:
                         self.stopEvent.set()
 
-        # stop the thread by signaling stopEvent
         def stop(self):
+            """stop the thread by signaling stopEvent"""
             self.stopEvent.set()
 
     # the singleton
     instance = None
+    lock = Lock()
 
     def __init__(self, observable):
-        if not CardMonitoringThread.instance:
-            CardMonitoringThread.instance = \
-               CardMonitoringThread.__CardMonitoringThreadSingleton(observable)
-            CardMonitoringThread.instance.start()
+        with CardMonitoringThread.lock:
+            if not CardMonitoringThread.instance:
+                CardMonitoringThread.instance = (
+                    CardMonitoringThread.__CardMonitoringThreadSingleton(observable)
+                )
+                CardMonitoringThread.instance.start()
 
     def join(self, *args, **kwargs):
-        if self.instance:
-            self.instance.join(*args, **kwargs)
-            CardMonitoringThread.instance = None
+        """wait for the CardMonitoringThread thread"""
+        with CardMonitoringThread.lock:
+            if self.instance:
+                self.instance.join(*args, **kwargs)
+                CardMonitoringThread.instance = None
 
     def __getattr__(self, name):
         if self.instance:
             return getattr(self.instance, name)
 
-    # commented to avoid bad clean-up sequence of python where __del__
-    # is called when some objects it uses are already gargabe collected
-    # def __del__(self):
-    #    if CardMonitoringThread.instance!=None:
-    #        CardMonitoringThread.instance.stop()
-    #        CardMonitoringThread.instance = None
+        raise SmartcardException(".instance is not set")
 
 
 if __name__ == "__main__":
-    print('insert or remove cards in the next 10 seconds')
+    print("insert or remove cards in the next 10 seconds")
 
-    # a simple card observer that prints added/removed cards
     class printobserver(CardObserver):
+        """a simple card observer that prints added/removed cards"""
 
         def __init__(self, obsindex):
             self.obsindex = obsindex
 
         def update(self, observable, handlers):
             addedcards, removedcards = handlers
-            print("%d - added:   %s" % (self.obsindex, str(addedcards)))
-            print("%d - removed: %s" % (self.obsindex, str(removedcards)))
+            print(f"{self.obsindex} - added:   {str(addedcards)}")
+            print(f"{self.obsindex} - removed: {str(removedcards)}")
 
     class testthread(Thread):
+        """Test class"""
 
         def __init__(self, obsindex):
             Thread.__init__(self)
